@@ -1,5 +1,6 @@
 from .applied_add_on import AppliedAddOn
 from .applied_coupon import AppliedCoupon
+from .applied_tax import AppliedTax
 from .billable_metric import BillableMetric, BillableMetricGroup
 from .charge import Charge, Charges, ChargesResponse
 from .coupon import Coupon, LimitationConfiguration
@@ -9,10 +10,13 @@ from .plan import Plan
 from .add_on import AddOn
 from .organization import Organization, OrganizationBillingConfiguration
 from .event import Event, BatchEvent
+from .fee import Fee
 from .customer import Customer, CustomerBillingConfiguration, Metadata, MetadataList
-from .invoice import InvoicePaymentStatusChange, Invoice, InvoiceMetadata, InvoiceMetadataList
+from .invoice import InvoicePaymentStatusChange, Invoice, InvoiceMetadata, InvoiceMetadataList,\
+    OneOffInvoice, InvoiceFeesList, InvoiceFee
 from .invoice_item import InvoiceItemResponse
 from .subscription import Subscription
 from .customer_usage import Metric, ChargeObject, ChargeUsage, CustomerUsageResponse
+from .tax import Tax, Taxes
 from .wallet import Wallet
 from .wallet_transaction import WalletTransaction
